What is config engine?
----------------------
A python module used for easy definition and access to configuration data.
Configuration can be read from either environment vars or from ini style files.

See the full `documentation <https://connectria.github.io/conf-engine>`_ for
more details.